summaryrefslogtreecommitdiffstats
path: root/kpf/src/Utils.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpf/src/Utils.h')
-rw-r--r--kpf/src/Utils.h44
1 files changed, 22 insertions, 22 deletions
diff --git a/kpf/src/Utils.h b/kpf/src/Utils.h
index 6a81dfa8..12e55507 100644
--- a/kpf/src/Utils.h
+++ b/kpf/src/Utils.h
@@ -24,10 +24,10 @@
#ifndef KPF_UTILS_H
#define KPF_UTILS_H
-#include <qstringlist.h>
-#include <qstring.h>
-#include <qdatetime.h>
-#include <qfileinfo.h>
+#include <tqstringlist.h>
+#include <tqstring.h>
+#include <tqdatetime.h>
+#include <tqfileinfo.h>
/**
* Used to keep all parts of the kpf application out of the global namespace.
@@ -49,63 +49,63 @@ namespace KPF
/**
* @return the current date and time as an HTTP/1.1 compliant date string.
*/
- QString dateString();
+ TQString dateString();
/**
* @return the passed QDateTime as an HTTP/1.1 compliant date string.
*/
- QString dateString(const QDateTime & dt);
+ TQString dateString(const TQDateTime & dt);
/**
* Parse an HTTP/1.1 date to a QDateTime.
* @param ret the QDateTime representation (result of parsing)
* @return true if the date is an an acceptable format.
*/
- bool parseDate(const QString &, QDateTime & ret);
+ bool parseDate(const TQString &, TQDateTime & ret);
/**
* Parse an RFC 1123 format date to a QDateTime. Usually called by
* @ref parseDate.
*/
- bool parseDateRFC1123(const QStringList &, QDateTime &);
+ bool parseDateRFC1123(const TQStringList &, TQDateTime &);
/**
* Parse an RFC 850 format date to a QDateTime. Usually called by
* @ref parseDate.
*/
- bool parseDateRFC850(const QStringList &, QDateTime &);
+ bool parseDateRFC850(const TQStringList &, TQDateTime &);
/**
* Parse an asctime(3) format date to a QDateTime. Usually called by
* @ref parseDate.
*/
- bool parseDateAscTime(const QStringList &, QDateTime &);
+ bool parseDateAscTime(const TQStringList &, TQDateTime &);
/**
* @return i18n(HTTP response message for code)
*/
- QString translatedResponseName(uint code);
+ TQString translatedResponseName(uint code);
/**
* @return HTTP response message for code
*/
- QString responseName(uint code);
+ TQString responseName(uint code);
/**
* @return the passed QDateTime converted GMT, honouring daylight
* saving time if necessary.
*/
- QDateTime toGMT(const QDateTime &);
+ TQDateTime toGMT(const TQDateTime &);
/**
* Unquote hex quoted chars in string.
*/
- QString unquote(const QString &);
+ TQString unquote(const TQString &);
/**
* Quote naughty chars in %xx format.
*/
- QString quote(const QString &);
+ TQString quote(const TQString &);
} // End namespace KPF
@@ -49,63 +49,63 @@ namespace KPF
/**
- * @return the passed QDateTime as an HTTP/1.1 compliant date string.
+ * @return the passed TQDateTime as an HTTP/1.1 compliant date string.
*/
@@ -49,63 +49,63 @@ namespace KPF
/**
- * Parse an HTTP/1.1 date to a QDateTime.
- * @param ret the QDateTime representation (result of parsing)
+ * Parse an HTTP/1.1 date to a TQDateTime.
+ * @param ret the TQDateTime representation (result of parsing)
* @return true if the date is an an acceptable format.
*/
@@ -49,63 +49,63 @@ namespace KPF
/**
- * Parse an RFC 1123 format date to a QDateTime. Usually called by
+ * Parse an RFC 1123 format date to a TQDateTime. Usually called by
* @ref parseDate.
*/
@@ -49,63 +49,63 @@ namespace KPF
/**
- * Parse an RFC 850 format date to a QDateTime. Usually called by
+ * Parse an RFC 850 format date to a TQDateTime. Usually called by
* @ref parseDate.
*/
@@ -49,63 +49,63 @@ namespace KPF
/**
- * Parse an asctime(3) format date to a QDateTime. Usually called by
+ * Parse an asctime(3) format date to a TQDateTime. Usually called by
* @ref parseDate.
*/
@@ -49,63 +49,63 @@ namespace KPF
/**
- * @return the passed QDateTime converted GMT, honouring daylight
+ * @return the passed TQDateTime converted GMT, honouring daylight
* saving time if necessary.
*/